/**
 * @fileoverview Module for utility code.
 */


/**
 * Function to implement nsIDOMEventListener by dispatching to on_* methods.
 *
 * This looks at event.type to dispatch to methods like on_mousedown.
 * Used to avoid a huge switch statement.
 *
 * @param {nsIDOMEvent} event The event to dispatch.
 */
function handleEvent(event) {
    let handler = this['on_' + event.type];
    if (handler === undefined)
        throw new Error(
            'RadialContext bug: Unhandled event type ' + event.type);

    handler.call(this, event);
}


var Timer = Components.Constructor('@mozilla.org/timer;1',
                                   'nsITimer', 'initWithCallback');
const TIMER_ONE_SHOT = Components.interfaces.nsITimer.TYPE_ONE_SHOT;
const TIMER_REPEATING_SLACK =
    Components.interfaces.nsITimer.TYPE_REPEATING_SLACK;
const TIMER_REPEATING_PRECISE =
    Components.interfaces.nsITimer.TYPE_REPEATING_PRECISE;

var RawTimer = Components.Constructor('@mozilla.org/timer;1', 'nsITimer');
